@@ -333,7 +333,11 @@ calc_intervals <- function(x, p, med = TRUE, ...) {
 #'   equivalent to using `legend_none()`.
 #'
 legend_move <- function(position = "right") {
-  theme(legend.position = position)
+  if (is.numeric(position) && "legend.position.inside" %in% fn_fmls_names(theme)) {
+    theme(legend.position = "inside", legend.position.inside = position)
+  } else {
+    theme(legend.position = position)
+  }
 }
 #' @rdname bayesplot-helpers
 #' @export
@@ -465,3 +469,53 @@ grid_lines_y <- function(color = "gray50", size = 0.2) {
 overlay_function <- function(...) {
   stat_function(..., inherit.aes = FALSE)
 }
+
+
+
+# Resolve a function name and store the expression passed in by the user
+#' @noRd
+#' @param f a function-like thing: a string naming a function, a function
+#'   object, an anonymous function object, a formula-based lambda, and `NULL`.
+#' @param fallback character string providing a fallback function name
+#' @return the function named in `f` with an added `"tagged_expr"` attribute
+#' containing the expression to represent the function name and an
+#' `"is_anonymous_function"` attribute to flag if the expression is a call to
+#' `function()`.
+as_tagged_function <- function(f = NULL, fallback = "func") {
+  qf <- enquo(f)
+  f <- eval_tidy(qf)
+  if (!is.null(attr(f, "tagged_expr"))) return(f)
+
+  f_expr <- quo_get_expr(qf)
+  f_fn <- f
+
+  if (is_character(f)) {        # f = "mean"
+    # using sym() on the evaluated `f` means that a variable that names a
+    # function string `x <- "mean"; as_tagged_function(x)` will be lost
+    # but that seems okay
+    f_expr <- sym(f)
+    f_fn <- match.fun(f)
+  } else if (is_null(f)) {      # f = NULL
+    f_fn <- identity
+    f_expr <- sym(fallback)
+  } else if (is_callable(f)) {  # f = mean or f = function(x) mean(x)
+    f_expr <- f_expr            # or f = ~mean(.x)
+    f_fn <- as_function(f)
+  }
+
+  # Setting attributes on primitive functions is deprecated, so wrap them
+  # and then tag
+  if (is_primitive(f_fn)) {
+    f_fn_old <- f_fn
+    f_factory <- function(f) { function(...) f(...) }
+    f_fn <- f_factory(f_fn_old)
+  }
+
+  attr(f_fn, "tagged_expr") <- f_expr
+  attr(f_fn, "is_anonymous_function") <-
+    is_call(f_expr, name = "function") || is_formula(f_expr)
+  f_fn
+}
+
+
+
