@@ -394,7 +394,7 @@ mcmc_violin <- function(
       set_hist_aes(freq),
       fill = get_color("mid"),
       color = get_color("mid_highlight"),
-      size = .25,
+      linewidth = .25,
       na.rm = TRUE,
       binwidth = binwidth,
       bins = bins,
@@ -472,7 +472,7 @@ mcmc_violin <- function(
     }
   }
 
-  geom_args <- list(size = 0.5, na.rm = TRUE, alpha = alpha)
+  geom_args <- list(linewidth = 0.5, na.rm = TRUE, alpha = alpha)
   if (violin) {
     geom_args[["draw_quantiles"]] <- probs
   } else {
