@@ -126,7 +126,7 @@
 #' color_scheme_set("purple")
 #' p <- mcmc_trace(
 #'   x,
-#'   regex_pars = "beta\\\[[1,3]\\\]",
+#'   regex_pars = "beta\\[[1,3]\\]",
 #'   facet_args = list(labeller = ggplot2::label_parsed)
 #' )
 #' p + facet_text(size = 15)
@@ -304,17 +304,28 @@ mcmc_rank_overlay <- function(x,
     mutate(cut = cut(.data$value_rank, n_bins)) %>%
     group_by(.data$cut) %>%
     mutate(bin_start = min(.data$value_rank)) %>%
-    ungroup() %>%
-    select(-c("cut"))
+    ungroup()
 
+  # Count how many values fall into each bin per chain & parameter
   d_bin_counts <- data %>%
     left_join(histobins, by = "value_rank") %>%
     count(.data$parameter, .data$chain, .data$bin_start)
 
+  # Now ensure that all combinations of parameter, chain, and bin_start exist
+  # even if no counts are present (https://github.com/stan-dev/bayesplot/issues/331)
+  all_combos <- dplyr::as_tibble(expand.grid(
+    parameter = unique(data$parameter),
+    chain = unique(data$chain),
+    bin_start = unique(histobins$bin_start),
+    stringsAsFactors = FALSE
+  ))
+  d_bin_counts <- all_combos %>%
+    left_join(d_bin_counts, by = c("parameter", "chain", "bin_start")) %>%
+    mutate(n = dplyr::if_else(is.na(n), 0L, n))
+
   # Duplicate the final bin, setting the left edge to the greatest x value, so
   # that the entire x-axis is used,
   right_edge <- max(data$value_rank)
-
   d_bin_counts <- d_bin_counts %>%
     dplyr::filter(.data$bin_start == max(.data$bin_start)) %>%
     mutate(bin_start = right_edge) %>%
@@ -335,7 +346,7 @@ mcmc_rank_overlay <- function(x,
 
   facet_call <- NULL
   if (n_param > 1) {
-    facet_args$facets <- ~ parameter
+    facet_args$facets <- vars(.data$parameter)
     facet_args$scales <- facet_args$scales %||% "fixed"
     facet_call <- do.call("facet_wrap", facet_args)
   }
@@ -387,14 +398,16 @@ mcmc_rank_hist <- function(x,
   right_edge <- max(data_boundaries$value_rank)
 
   facet_args[["scales"]] <- facet_args[["scales"]] %||% "fixed"
-  facet_args[["facets"]] <- facet_args[["facets"]] %||% (parameter ~ chain)
 
   # If there is one parameter, put the chains in one row.
   # Otherwise, use a grid.
   if (n_param > 1) {
     facet_f <- facet_grid
+    facet_args[["rows"]] <- facet_args[["rows"]] %||% vars(.data$parameter)
+    facet_args[["cols"]] <- facet_args[["cols"]] %||% vars(.data$chain)
   } else {
     facet_f <- facet_wrap
+    facet_args[["facets"]] <- vars(.data$parameter, .data$chain)
     facet_args[["nrow"]] <- facet_args[["nrow"]] %||% 1
     labeller <- function(x) label_value(x, multi_line = FALSE)
     facet_args[["labeller"]] <- facet_args[["labeller"]] %||% labeller
@@ -526,7 +539,7 @@ mcmc_rank_ecdf <-
   if (n_param == 1) {
     facet_call <- ylab(levels(data$parameter))
   } else {
-    facet_args$facets <- ~parameter
+    facet_args$facets <- vars(.data$parameter)
     facet_args$scales <- facet_args$scales %||% "free"
     facet_call <- do.call("facet_wrap", facet_args)
   }
@@ -663,7 +676,11 @@ mcmc_trace_data <- function(x,
   }
 
   geom_args <- list()
-  geom_args$size <- size %||% ifelse(style == "line", 1/3, 1)
+  if (style == "line") {
+    geom_args$linewidth = size %||% 1 / 3
+  } else {
+    geom_args$size = size %||% 1
+  }
   layer_draws <- do.call(paste0("geom_", style), geom_args)
 
   coord_window <- if (!is.null(window)) {
@@ -705,7 +722,7 @@ mcmc_trace_data <- function(x,
   if (n_param == 1) {
     facet_call <- ylab(levels(data$parameter))
   } else {
-    facet_args$facets <- ~ parameter
+    facet_args$facets <- vars(.data$parameter)
     facet_args$scales <- facet_args$scales %||% "free"
     facet_call <- do.call("facet_wrap", facet_args)
   }
