@@ -58,6 +58,22 @@ test_that("ppc_dens,pp_hist,ppc_freqpoly,ppc_boxplot return ggplot objects", {
   expect_gg(ppd_boxplot(yrep2, notch = FALSE))
 })
 
+test_that("ppc_dots returns a ggplot object", {
+  testthat::skip_if_not_installed("ggdist")
+
+  expect_gg(ppc_dots(y, yrep[1:8, ]))
+  expect_gg(ppc_dots(y, yrep[1,, drop = FALSE], quantiles = 25))
+  expect_gg(ppc_dots(y, yrep[1:8, ], binwidth = 0.1))
+  expect_gg(ppc_dots(y2, yrep2, binwidth = 0.1, quantiles = 25))
+
+  # ppd versions
+  expect_gg(ppd_dots(yrep[1:8, ]))
+  expect_gg(ppd_dots(yrep[1,, drop = FALSE], quantiles = 25))
+  expect_gg(ppd_dots(yrep[1:8, ], binwidth = 0.1))
+  expect_gg(ppd_dots(yrep2, binwidth = 0.1, quantiles = 25))
+
+})
+
 test_that("ppc_pit_ecdf, ppc_pit_ecdf_grouped returns a ggplot object", {
   expect_gg(ppc_pit_ecdf(y, yrep, interpolate_adj = FALSE))
   expect_gg(ppc_pit_ecdf_grouped(y, yrep, group = group, interpolate_adj = FALSE))
@@ -91,6 +107,7 @@ test_that("ppc_violin_grouped returns a ggplot object", {
 test_that("ppc_hist renders correctly", {
   testthat::skip_on_cran()
   testthat::skip_if_not_installed("vdiffr")
+  skip_on_r_oldrel()
 
   p_base <- ppc_hist(vdiff_y, vdiff_yrep[1:8, ])
   vdiffr::expect_doppelganger("ppc_hist (default)", p_base)
@@ -109,6 +126,7 @@ test_that("ppc_hist renders correctly", {
 test_that("ppc_freqpoly renders correctly", {
   testthat::skip_on_cran()
   testthat::skip_if_not_installed("vdiffr")
+  skip_on_r_oldrel()
 
   p_base <- ppc_freqpoly(vdiff_y, vdiff_yrep[1:8, ])
   vdiffr::expect_doppelganger("ppc_freqpoly (default)", p_base)
@@ -140,6 +158,7 @@ test_that("ppc_freqpoly renders correctly", {
 test_that("ppc_freqpoly_grouped renders correctly", {
   testthat::skip_on_cran()
   testthat::skip_if_not_installed("vdiffr")
+  skip_on_r_oldrel()
 
   p_base <- ppc_freqpoly_grouped(vdiff_y, vdiff_yrep[1:3, ], vdiff_group)
   vdiffr::expect_doppelganger("ppc_freqpoly_grouped (default)", p_base)
@@ -152,6 +171,7 @@ test_that("ppc_freqpoly_grouped renders correctly", {
 test_that("ppc_boxplot renders correctly", {
   testthat::skip_on_cran()
   testthat::skip_if_not_installed("vdiffr")
+  skip_on_r_oldrel()
 
   p_base <- ppc_boxplot(vdiff_y, vdiff_yrep[1:8, ])
   vdiffr::expect_doppelganger("ppc_boxplot (default)", p_base)
@@ -173,9 +193,46 @@ test_that("ppc_boxplot renders correctly", {
   vdiffr::expect_doppelganger("ppd_boxplot (alpha, size)", p_custom)
 })
 
+test_that("ppc_dots renders correctly", {
+  testthat::skip_on_cran()
+  testthat::skip_if_not_installed("vdiffr")
+  testthat::skip_if_not_installed("ggdist")
+  skip_on_r_oldrel()
+
+  p_base <- ppc_dots(vdiff_y, vdiff_yrep[1:8, ])
+  vdiffr::expect_doppelganger("ppc_dots (default)", p_base)
+
+  p_binwidth <- ppc_dots(vdiff_y, vdiff_yrep[1:8, ], binwidth = 3)
+  expect_warning(vdiffr::expect_doppelganger("ppc_dots (binwidth)", p_binwidth),
+                 "The provided binwidth will cause dots to overflow the boundaries")
+
+  p_quantile <- ppc_dots(vdiff_y, vdiff_yrep[1:8, ], quantiles = 50)
+  vdiffr::expect_doppelganger("ppc_dots (quantile)", p_quantile)
+
+  p_quantile_binwidth <- ppc_dots(vdiff_y, vdiff_yrep[1:8, ], binwidth = 3, quantiles = 50)
+  expect_warning(vdiffr::expect_doppelganger("ppc_dots (quantile-binwidth)", p_quantile_binwidth),
+                 "The provided binwidth will cause dots to overflow the boundaries")
+
+  # ppd versions
+  p_base <- ppd_dots(vdiff_yrep[1:8, ])
+  vdiffr::expect_doppelganger("ppd_dots (default)", p_base)
+
+  p_binwidth <- ppd_dots(vdiff_yrep[1:8, ], binwidth = 3)
+  expect_warning(vdiffr::expect_doppelganger("ppd_dots (binwidth)", p_binwidth),
+                 "The provided binwidth will cause dots to overflow the boundaries")
+
+  p_quantile <- ppd_dots(vdiff_yrep[1:8, ], quantiles = 50)
+  vdiffr::expect_doppelganger("ppd_dots (quantile)", p_quantile)
+
+  p_quantile_binwidth <- ppd_dots(vdiff_yrep[1:8, ], binwidth = 3, quantiles = 50)
+  expect_warning(vdiffr::expect_doppelganger("ppd_dots (quantile-binwidth)", p_quantile_binwidth),
+                 "The provided binwidth will cause dots to overflow the boundaries")
+})
+
 test_that("ppc_ecdf_overlay renders correctly", {
   testthat::skip_on_cran()
   testthat::skip_if_not_installed("vdiffr")
+  skip_on_r_oldrel()
 
   p_base <- ppc_ecdf_overlay(vdiff_y2, vdiff_yrep2)
   vdiffr::expect_doppelganger("ppc_ecdf_overlay (default)", p_base)
@@ -196,6 +253,8 @@ test_that("ppc_ecdf_overlay renders correctly", {
 
 test_that("ppc_ecdf_overlay_grouped renders correctly", {
   testthat::skip_on_cran()
+  testthat::skip_if_not_installed("vdiffr")
+  skip_on_r_oldrel()
 
   p_base <- ppc_ecdf_overlay_grouped(vdiff_y2, vdiff_yrep2, vdiff_group2)
   vdiffr::expect_doppelganger("ppc_ecdf_overlay_grouped (default)", p_base)
@@ -218,6 +277,7 @@ test_that("ppc_ecdf_overlay_grouped renders correctly", {
 test_that("ppc_dens renders correctly", {
   testthat::skip_on_cran()
   testthat::skip_if_not_installed("vdiffr")
+  skip_on_r_oldrel()
 
   p_base <- ppc_dens(vdiff_y, vdiff_yrep[1:8, ])
   vdiffr::expect_doppelganger("ppc_dens (default)", p_base)
@@ -230,6 +290,7 @@ test_that("ppc_dens renders correctly", {
 test_that("ppc_dens_overlay renders correctly", {
   testthat::skip_on_cran()
   testthat::skip_if_not_installed("vdiffr")
+  skip_on_r_oldrel()
 
   p_base <- ppc_dens_overlay(vdiff_y, vdiff_yrep)
   vdiffr::expect_doppelganger("ppc_dens_overlay (default)", p_base)
@@ -247,6 +308,8 @@ test_that("ppc_dens_overlay renders correctly", {
 
 test_that("ppc_dens_overlay_grouped renders correctly", {
   testthat::skip_on_cran()
+  testthat::skip_if_not_installed("vdiffr")
+  skip_on_r_oldrel()
 
   p_base <- ppc_dens_overlay_grouped(vdiff_y, vdiff_yrep, vdiff_group)
   vdiffr::expect_doppelganger("ppc_dens_overlay_grouped (default)", p_base)
@@ -269,6 +332,7 @@ test_that("ppc_violin_grouped renders correctly", {
   testthat::skip_on_cran()
   testthat::skip_if_not(getRversion() >= "3.6.0")
   testthat::skip_if_not_installed("vdiffr")
+  skip_on_r_oldrel()
 
   p_base <- ppc_violin_grouped(vdiff_y, vdiff_yrep, vdiff_group)
   vdiffr::expect_doppelganger("ppc_violin_grouped (default)", p_base)
@@ -300,6 +364,7 @@ test_that("ppc_violin_grouped renders correctly", {
 test_that("ppc_pit_ecdf, ppc_pit_ecdf_grouped renders correctly", {
   testthat::skip_on_cran()
   testthat::skip_if_not_installed("vdiffr")
+  skip_on_r_oldrel()
 
   p_base <- ppc_pit_ecdf(y, yrep, interpolate_adj = FALSE)
   g_base <- ppc_pit_ecdf_grouped(y, yrep, group = group, interpolate_adj = FALSE)
